#ifdef __cplusplus
extern "C" {
#endif

#include "uulib/unpack.h"

#ifdef __cplusplus
}
#endif

void uu_unpack(pUCXT, const uu_t in, struct uu *out) {
  const U8  *ptr = in;
  U32       tmp;

  tmp = *ptr++;
  tmp = (tmp << 8) | *ptr++;
  tmp = (tmp << 8) | *ptr++;
  tmp = (tmp << 8) | *ptr++;
  out->time_low = tmp;

  tmp = *ptr++;
  tmp = (tmp << 8) | *ptr++;
  out->time_mid = (U16)tmp;

  tmp = *ptr++;
  tmp = (tmp << 8) | *ptr++;
  out->time_high_and_version = (U16)tmp;

  tmp = *ptr++;
  tmp = (tmp << 8) | *ptr++;
  out->clock_seq_and_variant = (U16)tmp;

  out->node[0] = *ptr++;
  out->node[1] = *ptr++;
  out->node[2] = *ptr++;
  out->node[3] = *ptr++;
  out->node[4] = *ptr++;
  out->node[5] = *ptr;
}

/* ex:set ts=2 sw=2 itab=spaces: */
